NumericIndex

Struct NumericIndex 

pub struct NumericIndex { /* private fields */ }

Implementations

Source

impl NumericIndex

pub fn new(i: Integer) -> Self

pub fn span(&self) -> Option<Span>

pub fn sign(&self) -> Option<Sign>

Returns the sign token for this integer.

pub fn src(&self) -> &str

Returns the original source text for this integer.

pub fn val(&self) -> (Option<&String>, Option<u32>)

Returns the value string that can be parsed for this integer, as well as the base that it should be parsed in